#
# spec file for package perl-Mojo-IOLoop-ReadWriteProcess
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojo-IOLoop-ReadWriteProcess
Name:           perl-Mojo-IOLoop-ReadWriteProcess
Version:        0.33
Release:        2.1
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Execute external programs or internal code blocks as separate process
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SZ/SZARATE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
# PATCH-FIX-UPSTREAM https://github.com/openSUSE/Mojo-IOLoop-ReadWriteProcess/pull/51
Patch0:         deprecated-spurt.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IPC::SharedMem)
BuildRequires:  perl(Module::Build) >= 0.4005
BuildRequires:  perl(Mojolicious)
BuildRequires:  perl(Test::Exception)
Requires:       perl(IPC::SharedMem)
Requires:       perl(Mojolicious)
%{perl_requires}

%description
Mojo::IOLoop::ReadWriteProcess is yet another process manager.

%prep
%autosetup  -n %{cpan_name}-%{version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md
%license LICENSE

%changelog
* Fri Sep 15 2023 Tina Müller <tina.mueller@suse.com>
- Add patch deprecated-spurt.patch
  https://github.com/openSUSE/Mojo-IOLoop-ReadWriteProcess/pull/51
* Mon Dec 12 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.33
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.33 2022-12-12T12:22:13Z
  - Apply perltidy v20221112
  - remove hard-coding of OABI syscall entry point
  - Fix typos detected by lintian (Debian) (#47)
  - tests: Check executable, before using it in tests
  - Fix sporadic 01_run.t failure -- "process is still running"
  - Fix all .perltidyrc violations
  - Run perltidy for pull requests
  - Add test for SIG_CHLD handler in spawned process
* Mon Dec 13 2021 Oliver Kurz <okurz@suse.com>
- Enable previously unstable build-tests again
  https://github.com/openSUSE/Mojo-IOLoop-ReadWriteProcess/issues/14
* Mon Dec 13 2021 Oliver Kurz <okurz@suse.com>
- Update project URL references
* Fri Dec 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.32
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.32 2021-12-09T18:03:02Z
  - Project moved to https://github.com/openSUSE/Mojo-IOLoop-ReadWriteProcess
  - Introduce emit_from_sigchld()
  - CI moved to GitHub Actions
* Thu Dec  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.31
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.31 2021-12-01T15:51:06Z
  - Fix bad release to cpan
  - Enable GitHub Actions for the project
  - Fix ReadWriteProcess::Queue as regression of 1e0addb6
  - Fix race on `open3/fork` and `session->register($pid)` call -- second attempt
  - Fix `args` processing
  - Fix race of SIG{CHLD} handler setup
  - Fix _getlines() to avoid extra newline (\n) in scalar context
  - Session: Do not set SIG{CHLD} handler twice
  - Match on 'armv7l' as well as 'arm' for prctl detection
* Thu Apr 29 2021 Oliver Kurz <okurz@suse.com>
- Ignore more unstable tests (https://github.com/mudler/Mojo-IOLoop-ReadWriteProcess/issues/14)
* Fri Nov 13 2020 Oliver Kurz <okurz@suse.com>
- Ignore unstable tests (https://github.com/mudler/Mojo-IOLoop-ReadWriteProcess/issues/14)
* Sun Oct  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.28
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.28 2020-09-30T11:51:40Z
  - Avoid executing "blocking stop" code when process has already terminated by Martchus
* Fri Jul  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.27
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
* Thu Apr  9 2020 <timueller+perl@suse.de>
- updated to 0.25
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.25 2020-04-08T14:48:01Z
  - In "stop" sleep only after sending the first signal to speedup termination by okurz
  - Various fixups in test suite
* Fri Oct 18 2019 <timueller+perl@suse.de>
- Change the `find` call for modifying permissions to leave also shell scripts
  and files in the t/ directory alone
* Wed Oct 16 2019 <timueller+perl@suse.de>
- updated to 0.24
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.24 2019-10-15T11:11:50Z
  - Fix compatibility with Mojolicious 8.23 by kraih
* Fri Oct 11 2019 Oliver Kurz <okurz@suse.com>
- Exclude non-working tests with perl-Mojolicious >= 8.23
  See https://github.com/mudler/Mojo-IOLoop-ReadWriteProcess/issues/4
  for details
* Tue Aug 14 2018 edigiacinto@suse.com
- Add prctl syscall codes for ppc64le and aarch64
- Full test suite now runs only on travis
* Tue Aug  7 2018 edigiacinto@suse.com
- Disable experimental shared tests by default
* Tue Aug  7 2018 edigiacinto@suse.com
- Add Experimental Mojo::IOLoop::ReadWriteProcess::Shared::* for IPC (Lock, Memory, Sempahores)
- Add possibility to turn off channels only
- Fix incorrect handling of return in case internal_pipes is disabled
- Provide alternative exit status computation for exotic arches/setup
* Tue Mar 27 2018 edigiacinto@suse.com
- updated to 0.20
  0.20 2018-03-26T13:32:58Z
  - Add preliminar CGroup support
  - Add also interface to unshare() syscall
  - Add mocked test, still needs to be documented in POD
* Mon Feb 26 2018 edigiacinto@suse.com
- updated to 0.19
  0.19 2018-02-22T13:41:50Z
  - Minor bugfixes to Session
  - Make session constructor fixed
  0.18 2018-02-21T12:01:07Z
  - Guard stop() from possible race conditions
  - Fix typo in Session, it caused orphan processes to not be resolved correctly
  0.17 2018-02-20T14:01:59Z
  - Fix minor issue in tests, stabilize serialize test and events
  - Reset session and subreaper bit on forked child process
* Mon Feb 19 2018 edigiacinto@suse.com
- updated to 0.16
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.16 2018-02-19T13:32:54Z
  - Fix minor issue in event test that made them unstable
  0.15 2018-02-19T10:13:22Z
  - Fix skipping subreaper tests on unsupported platforms
  - Reset session before invoking child callback
  0.14 2018-02-18T21:08:17Z
  - Fix race condition in Mojo::IOLoop::ReadWriteProcess::Queue
  0.13 2018-02-17T19:34:51Z
  - Move subreaper and subprocess logics to Mojo::IOLoop::ReadWriteProcess::Session
  - Use Mojo::IOLoop::ReadWriteProcess::Session as global collector handler
  0.12 2018-02-16T12:53:26Z
  - Enhance tests
  - Add experimental subreaper and subprocess support
* Mon Feb 12 2018 coolo@suse.com
- updated to 0.11
  see /usr/share/doc/packages/perl-Mojo-IOLoop-ReadWriteProcess/Changes
  0.11 2018-02-12T09:32:05Z
  - update cpanfile requirements (requires Module::Build now)
  - update POD
* Mon Feb 12 2018 coolo@suse.com
- initial package 0.10
  * created by cpanspec 1.78.08
